// -*- MaTX -*-

// hplot.mm: includes hmultiplot() and
//           is the test suite for Makefile in complicated conditions
//
//   Originally written by KIYOTA Hiromitsu <1999/01/24>
//   Copyright (c) 1999 Hiromitsu Kiyota, kiyota@ds.mei.titech.ac.jp
//
// RCS: $Id: hplot.mm,v 1.3 1999/05/31 03:01:13 kiyota Exp $


// hmultiplot() plots T-XU graphs selectively wrt names("-" means the row to
// omit) in as many windows as necessary with MAX_ROW graphs at most in
// each of them.  It receives a window descriptor as the first argument,
// and returns the next free one.

// By mgplot_subplot(), or its default settings for Gnuplot, of today,
// the keys, or legends, of the graphs may be omitted when MAX_ROW >= 6.
#define MAX_ROW 4

// Sometimes, the last graph to draw in a window is not drawn in Gnuplot.
// I don't know why exactly for now. ;p
// Anyway, a few seconds of pause would help.
//#define PAUSE 0.5

Func Integer
hmultiplot(win, T, XU, names, replot, ...)
     Integer win;
     Matrix T, XU;
     List names;
     Integer replot; // 0(default): plot  1: replot
{
  Integer num, wnum, rows;
  Integer i, j, k;

  if (win < 1)
    {
      error("hmultiplot(): Incorrect window descriptor.\n");
    }

  num = 0;
  for (i = 1; i <= length(names); ++i)
    {
      if (names(i, String) != "-") { ++num; }
    }

  if (num == 0)
    {
//      error("hmultiplot(): No graph to draw.\n");
      return win;
    }

  wnum = Integer(ceil(Real(num)/MAX_ROW));
  rows = num/wnum;

  k = 1;
  for (i = 1; i <= wnum; {++i, ++win})
    {
      for (j = 1; j <= rows + (i <= num - rows*wnum); {++j, ++k})
	{
	  while (names(k, String) == "-") { ++k; }
	  mgplot_hold(win, 1);
	  mgplot_subplot(win, rows + (1 <= num - rows*wnum), 1, j);
	  mgplot_grid(win, 1);
	  if (! replot)
	    {
	      mgplot(win, T(1,:), XU(k,:), {names(k, String)});
	    }
	  else
	    {
	      mgreplot(win, T(1,:), XU(k,:), {names(k, String)});
	    }
	  mgplot_hold(win, 0);
#ifdef PAUSE
	  pause PAUSE;
#endif /* PAUSE */
	}
    }

  return win;
}
